@@ -442,8 +442,10 @@ def _copy_files_from_array(file_list, ftp=None, attempted_delete=False):
     for file in file_list:
         try:
             if ftp is not None:
+                ftp.makedirs(os.path.dirname(file['dst_path']))
                 ftp.upload_if_newer(file['src_path'], file['dst_path'])
                 continue
+
             os.makedirs(os.path.dirname(file['dst_path']), exist_ok=True)
             shutil.copy2(file['src_path'], file['dst_path'])
         except PermissionError as error:
@@ -681,11 +683,11 @@ def get_modified_time(file_path, ftp=None):
         `method_name`: get_modified_time
     '''
     if ftp is not None:
-        return datetime.timestamp(datetime.utcfromtimestamp(ftp.path.getmtime(file_path)))
+        return int(datetime.timestamp(datetime.utcfromtimestamp(ftp.path.getmtime(file_path))))
 
     mod_time = os.path.getmtime(file_path)
     mod_time = int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
-    return datetime.timestamp(datetime.fromtimestamp(mod_time))
+    return int(datetime.timestamp(datetime.fromtimestamp(mod_time)))
 
 
 def get_access_time(file_path):
